# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergySavingsChild(Model):
    """EnergySavingsChild.

    :param energy_savings: The energy savings amount
    :type energy_savings: float
    :param energy_savings_unit:
    :type energy_savings_unit: ~energycap.sdk.models.EnergySavingsUnit
    """

    _attribute_map = {
        'energy_savings': {'key': 'energySavings', 'type': 'float'},
        'energy_savings_unit': {'key': 'energySavingsUnit', 'type': 'EnergySavingsUnit'},
    }

    def __init__(self, **kwargs):
        super(EnergySavingsChild, self).__init__(**kwargs)
        self.energy_savings = kwargs.get('energy_savings', None)
        self.energy_savings_unit = kwargs.get('energy_savings_unit', None)
