# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarSubmissionPlaceChild(Model):
    """EnergyStarSubmissionPlaceChild.

    All required parameters must be populated in order to send to Azure.

    :param place_id: Required. The place identifier <span
     class='property-internal'>Required</span>
    :type place_id: int
    :param submission_periods: Required. The list of submission periods to
     include in the submission <span class='property-internal'>Required</span>
     <span class='property-internal'>Cannot be Empty</span>
    :type submission_periods: list[int]
    """

    _validation = {
        'place_id': {'required': True},
        'submission_periods': {'required': True},
    }

    _attribute_map = {
        'place_id': {'key': 'placeId', 'type': 'int'},
        'submission_periods': {'key': 'submissionPeriods', 'type': '[int]'},
    }

    def __init__(self, **kwargs):
        super(EnergyStarSubmissionPlaceChild, self).__init__(**kwargs)
        self.place_id = kwargs.get('place_id', None)
        self.submission_periods = kwargs.get('submission_periods', None)
