# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ContactChild(Model):
    """ContactChild.

    :param contact_id: The contact identifier
    :type contact_id: int
    :param first: The contact's first name
    :type first: str
    :param middle: The contact's middle name
    :type middle: str
    :param last: The contact's last name
    :type last: str
    """

    _attribute_map = {
        'contact_id': {'key': 'contactId', 'type': 'int'},
        'first': {'key': 'first', 'type': 'str'},
        'middle': {'key': 'middle', 'type': 'str'},
        'last': {'key': 'last', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ContactChild, self).__init__(**kwargs)
        self.contact_id = kwargs.get('contact_id', None)
        self.first = kwargs.get('first', None)
        self.middle = kwargs.get('middle', None)
        self.last = kwargs.get('last', None)
