# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FlagStatusChild(Model):
    """FlagStatusChild.

    :param flag_status_id: The flag status identifier
    :type flag_status_id: int
    :param flag_status_info: Flag status information
    :type flag_status_info: str
    """

    _attribute_map = {
        'flag_status_id': {'key': 'flagStatusId', 'type': 'int'},
        'flag_status_info': {'key': 'flagStatusInfo', 'type': 'str'},
    }

    def __init__(self, *, flag_status_id: int=None, flag_status_info: str=None, **kwargs) -> None:
        super(FlagStatusChild, self).__init__(**kwargs)
        self.flag_status_id = flag_status_id
        self.flag_status_info = flag_status_info
