# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TagChild(Model):
    """TagChild.

    :param tag_type_id:
    :type tag_type_id: int
    :param tag_type_info:
    :type tag_type_info: str
    :param values:
    :type values: list[str]
    """

    _attribute_map = {
        'tag_type_id': {'key': 'tagTypeId', 'type': 'int'},
        'tag_type_info': {'key': 'tagTypeInfo', 'type': 'str'},
        'values': {'key': 'values', 'type': '[str]'},
    }

    def __init__(self, *, tag_type_id: int=None, tag_type_info: str=None, values=None, **kwargs) -> None:
        super(TagChild, self).__init__(**kwargs)
        self.tag_type_id = tag_type_id
        self.tag_type_info = tag_type_info
        self.values = values
