# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ShareResponse(Model):
    """ShareResponse.

    :param shared_with_everyone: True if the item is shared with everyone
    :type shared_with_everyone: bool
    :param shared_users: The list of individual users an item has been
     assigned to be shared with
     This does NOT take into account users that are in a shared user group
    :type shared_users: list[~energycap.sdk.models.UserChild]
    :param shared_user_groups: The list of user groups an item has been
     assigned to be shared with
    :type shared_user_groups: list[~energycap.sdk.models.UserGroupChild]
    """

    _attribute_map = {
        'shared_with_everyone': {'key': 'sharedWithEveryone', 'type': 'bool'},
        'shared_users': {'key': 'sharedUsers', 'type': '[UserChild]'},
        'shared_user_groups': {'key': 'sharedUserGroups', 'type': '[UserGroupChild]'},
    }

    def __init__(self, *, shared_with_everyone: bool=None, shared_users=None, shared_user_groups=None, **kwargs) -> None:
        super(ShareResponse, self).__init__(**kwargs)
        self.shared_with_everyone = shared_with_everyone
        self.shared_users = shared_users
        self.shared_user_groups = shared_user_groups
