# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountConnectionStatusResponse(Model):
    """AccountConnectionStatusResponse.

    :param connectable: When true this database is connectable to Portfolio
     Manager
    :type connectable: bool
    :param other_database_registered: Whether some other database is
     registered to portfolio manager or not
    :type other_database_registered: bool
    """

    _attribute_map = {
        'connectable': {'key': 'connectable', 'type': 'bool'},
        'other_database_registered': {'key': 'otherDatabaseRegistered', 'type': 'bool'},
    }

    def __init__(self, *, connectable: bool=None, other_database_registered: bool=None, **kwargs) -> None:
        super(AccountConnectionStatusResponse, self).__init__(**kwargs)
        self.connectable = connectable
        self.other_database_registered = other_database_registered
