# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestEnergyUseIntensity(Model):
    """PlaceDigestEnergyUseIntensity.

    :param period_name: The calendar period name
    :type period_name: str
    :param calendar_period: The calendar period number
    :type calendar_period: int
    :param calendar_year: The calendar year
    :type calendar_year: int
    :param use_per_area_trend: The running average use per area for the prior
     12 months
    :type use_per_area_trend: float
    :param global_use_unit:
    :type global_use_unit: ~energycap.sdk.models.UnitChild
    :param energy_projects: A list of energy projects for this building. To be
     listed, a project must end in this period.
     Projects are only displayed at the building level, but not at the
     organization level
    :type energy_projects:
     list[~energycap.sdk.models.PlaceDigestEnergyUseIntensityEuiEnergyProject]
    :param commodities: A breakdown of use per commodity
    :type commodities:
     list[~energycap.sdk.models.PlaceDigestEnergyUseIntensityEuiCommodity]
    """

    _attribute_map = {
        'period_name': {'key': 'periodName', 'type': 'str'},
        'calendar_period': {'key': 'calendarPeriod', 'type': 'int'},
        'calendar_year': {'key': 'calendarYear', 'type': 'int'},
        'use_per_area_trend': {'key': 'usePerAreaTrend', 'type': 'float'},
        'global_use_unit': {'key': 'globalUseUnit', 'type': 'UnitChild'},
        'energy_projects': {'key': 'energyProjects', 'type': '[PlaceDigestEnergyUseIntensityEuiEnergyProject]'},
        'commodities': {'key': 'commodities', 'type': '[PlaceDigestEnergyUseIntensityEuiCommodity]'},
    }

    def __init__(self, *, period_name: str=None, calendar_period: int=None, calendar_year: int=None, use_per_area_trend: float=None, global_use_unit=None, energy_projects=None, commodities=None, **kwargs) -> None:
        super(PlaceDigestEnergyUseIntensity, self).__init__(**kwargs)
        self.period_name = period_name
        self.calendar_period = calendar_period
        self.calendar_year = calendar_year
        self.use_per_area_trend = use_per_area_trend
        self.global_use_unit = global_use_unit
        self.energy_projects = energy_projects
        self.commodities = commodities
