# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class NotificationSettingsResponse(Model):
    """NotificationSettingsResponse.

    :param allow_users_to_email_notifications: Are user's allowed to get email
     notifications
    :type allow_users_to_email_notifications: bool
    :param notification_settings: The list of notification settings available
     and their configured value
    :type notification_settings:
     list[~energycap.sdk.models.NotificationSettingResponse]
    """

    _attribute_map = {
        'allow_users_to_email_notifications': {'key': 'allowUsersToEmailNotifications', 'type': 'bool'},
        'notification_settings': {'key': 'notificationSettings', 'type': '[NotificationSettingResponse]'},
    }

    def __init__(self, **kwargs):
        super(NotificationSettingsResponse, self).__init__(**kwargs)
        self.allow_users_to_email_notifications = kwargs.get('allow_users_to_email_notifications', None)
        self.notification_settings = kwargs.get('notification_settings', None)
