# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportGroupResponse(Model):
    """ReportGroupResponse.

    :param report_group_id:
    :type report_group_id: int
    :param report_group_code:
    :type report_group_code: str
    :param report_group_info:
    :type report_group_info: str
    :param reports:
    :type reports: list[~energycap.sdk.models.ReportChild]
    """

    _attribute_map = {
        'report_group_id': {'key': 'reportGroupId', 'type': 'int'},
        'report_group_code': {'key': 'reportGroupCode', 'type': 'str'},
        'report_group_info': {'key': 'reportGroupInfo', 'type': 'str'},
        'reports': {'key': 'reports', 'type': '[ReportChild]'},
    }

    def __init__(self, **kwargs):
        super(ReportGroupResponse, self).__init__(**kwargs)
        self.report_group_id = kwargs.get('report_group_id', None)
        self.report_group_code = kwargs.get('report_group_code', None)
        self.report_group_info = kwargs.get('report_group_info', None)
        self.reports = kwargs.get('reports', None)
