# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TemplateVendorLineRequest(Model):
    """TemplateVendorLineRequest.

    All required parameters must be populated in order to send to Azure.

    :param observation_type_id: Required. Specifies the type of line to create
     Only cost observation types are allowed
     To get the valid list of observation type ids call the GetObservationTypes
     API with ?filter=nounId one of '4'|'6'|'23' <span
     class='property-internal'>Required</span>
    :type observation_type_id: int
    :param caption: Required. The label for this line, that will be shown on
     the bill <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type caption: str
    """

    _validation = {
        'observation_type_id': {'required': True},
        'caption': {'required': True, 'max_length': 32, 'min_length': 0},
    }

    _attribute_map = {
        'observation_type_id': {'key': 'observationTypeId', 'type': 'int'},
        'caption': {'key': 'caption', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(TemplateVendorLineRequest, self).__init__(**kwargs)
        self.observation_type_id = kwargs.get('observation_type_id', None)
        self.caption = kwargs.get('caption', None)
