# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarPlaceSubmissionStatusResponse(Model):
    """EnergyStarPlaceSubmissionStatusResponse.

    :param place_id: The place identifier
    :type place_id: int
    :param place_info: The place name
    :type place_info: str
    :param place_code: The place code
    :type place_code: str
    :param place_submission_type:
    :type place_submission_type: ~energycap.sdk.models.SubmissionTypeResponse
    :param place_size:
    :type place_size: ~energycap.sdk.models.PlaceSizeChild
    :param place_submission_status: The list of submission periods and the
     submission status for each period
    :type place_submission_status:
     list[~energycap.sdk.models.EnergyStarPlaceSubmissionStatusChild]
    """

    _attribute_map = {
        'place_id': {'key': 'placeId', 'type': 'int'},
        'place_info': {'key': 'placeInfo', 'type': 'str'},
        'place_code': {'key': 'placeCode', 'type': 'str'},
        'place_submission_type': {'key': 'placeSubmissionType', 'type': 'SubmissionTypeResponse'},
        'place_size': {'key': 'placeSize', 'type': 'PlaceSizeChild'},
        'place_submission_status': {'key': 'placeSubmissionStatus', 'type': '[EnergyStarPlaceSubmissionStatusChild]'},
    }

    def __init__(self, **kwargs):
        super(EnergyStarPlaceSubmissionStatusResponse, self).__init__(**kwargs)
        self.place_id = kwargs.get('place_id', None)
        self.place_info = kwargs.get('place_info', None)
        self.place_code = kwargs.get('place_code', None)
        self.place_submission_type = kwargs.get('place_submission_type', None)
        self.place_size = kwargs.get('place_size', None)
        self.place_submission_status = kwargs.get('place_submission_status', None)
