# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ProjectManagerResponse(Model):
    """ProjectManagerResponse.

    :param project_manager_full_name: The full name of project manager
    :type project_manager_full_name: str
    :param project_manager_code: The code for project manager
    :type project_manager_code: str
    """

    _attribute_map = {
        'project_manager_full_name': {'key': 'projectManagerFullName', 'type': 'str'},
        'project_manager_code': {'key': 'projectManagerCode', 'type': 'str'},
    }

    def __init__(self, *, project_manager_full_name: str=None, project_manager_code: str=None, **kwargs) -> None:
        super(ProjectManagerResponse, self).__init__(**kwargs)
        self.project_manager_full_name = project_manager_full_name
        self.project_manager_code = project_manager_code
