# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Reviewed(Model):
    """Reviewed.

    :param reviewed: Indicates whether or not the savings has been reviewed
    :type reviewed: bool
    :param reviewed_by:
    :type reviewed_by: ~energycap.sdk.models.UserChild
    :param reviewed_date: Reviewed date
    :type reviewed_date: datetime
    """

    _attribute_map = {
        'reviewed': {'key': 'reviewed', 'type': 'bool'},
        'reviewed_by': {'key': 'reviewedBy', 'type': 'UserChild'},
        'reviewed_date': {'key': 'reviewedDate', 'type': 'iso-8601'},
    }

    def __init__(self, **kwargs):
        super(Reviewed, self).__init__(**kwargs)
        self.reviewed = kwargs.get('reviewed', None)
        self.reviewed_by = kwargs.get('reviewed_by', None)
        self.reviewed_date = kwargs.get('reviewed_date', None)
