# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillHeaderWorkflowChild(Model):
    """BillHeaderWorkflowChild.

    :param use_field:
    :type use_field: bool
    :param required:
    :type required: bool
    """

    _attribute_map = {
        'use_field': {'key': 'useField', 'type': 'bool'},
        'required': {'key': 'required', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(BillHeaderWorkflowChild, self).__init__(**kwargs)
        self.use_field = kwargs.get('use_field', None)
        self.required = kwargs.get('required', None)
