# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UserGroupChild(Model):
    """UserGroupChild.

    :param user_group_id: The user group identifier
    :type user_group_id: int
    :param user_group_name: The user group name
    :type user_group_name: str
    """

    _attribute_map = {
        'user_group_id': {'key': 'userGroupId', 'type': 'int'},
        'user_group_name': {'key': 'userGroupName', 'type': 'str'},
    }

    def __init__(self, *, user_group_id: int=None, user_group_name: str=None, **kwargs) -> None:
        super(UserGroupChild, self).__init__(**kwargs)
        self.user_group_id = user_group_id
        self.user_group_name = user_group_name
