# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarCommodityMeterTypeMapping(Model):
    """EnergyStarCommodityMeterTypeMapping.

    :param submission_unit:
    :type submission_unit: ~energycap.sdk.models.UnitChild
    :param portfolio_manager_commodity_mapping:
    :type portfolio_manager_commodity_mapping:
     ~energycap.sdk.models.EnergyStarCommodityMeterTypeMappingChild
    :param commodity_id: The commodity identifier
    :type commodity_id: int
    :param commodity_code: The commodity code
    :type commodity_code: str
    :param commodity_info: The commodity info
    :type commodity_info: str
    """

    _attribute_map = {
        'submission_unit': {'key': 'submissionUnit', 'type': 'UnitChild'},
        'portfolio_manager_commodity_mapping': {'key': 'portfolioManagerCommodityMapping', 'type': 'EnergyStarCommodityMeterTypeMappingChild'},
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'commodity_code': {'key': 'commodityCode', 'type': 'str'},
        'commodity_info': {'key': 'commodityInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(EnergyStarCommodityMeterTypeMapping, self).__init__(**kwargs)
        self.submission_unit = kwargs.get('submission_unit', None)
        self.portfolio_manager_commodity_mapping = kwargs.get('portfolio_manager_commodity_mapping', None)
        self.commodity_id = kwargs.get('commodity_id', None)
        self.commodity_code = kwargs.get('commodity_code', None)
        self.commodity_info = kwargs.get('commodity_info', None)
