# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UserRoleRequest(Model):
    """UserRoleRequest.

    :param user_role_id: The user role id to set for the user <span
     class='property-internal'>Required (defined)</span>
    :type user_role_id: int
    """

    _attribute_map = {
        'user_role_id': {'key': 'userRoleId', 'type': 'int'},
    }

    def __init__(self, *, user_role_id: int=None, **kwargs) -> None:
        super(UserRoleRequest, self).__init__(**kwargs)
        self.user_role_id = user_role_id
