# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarSettingsRequest(Model):
    """EnergyStarSettingsRequest.

    All required parameters must be populated in order to send to Azure.

    :param pm_user_name: The user name of the Portfolio Manager account to
     link. Not required if account already registered. <span
     class='property-internal'>Must be between 0 and 128 characters</span>
    :type pm_user_name: str
    :param earliest_submission_period: Required. The earliest period to submit
     <span class='property-internal'>Required</span>
    :type earliest_submission_period: int
    """

    _validation = {
        'pm_user_name': {'max_length': 128, 'min_length': 0},
        'earliest_submission_period': {'required': True},
    }

    _attribute_map = {
        'pm_user_name': {'key': 'pmUserName', 'type': 'str'},
        'earliest_submission_period': {'key': 'earliestSubmissionPeriod', 'type': 'int'},
    }

    def __init__(self, *, earliest_submission_period: int, pm_user_name: str=None, **kwargs) -> None:
        super(EnergyStarSettingsRequest, self).__init__(**kwargs)
        self.pm_user_name = pm_user_name
        self.earliest_submission_period = earliest_submission_period
