# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UserGroupWithMembers(Model):
    """UserGroupWithMembers.

    :param members: List of user group members
    :type members: list[~energycap.sdk.models.UserChildWithEmail]
    :param user_group_id: The user group identifier
    :type user_group_id: int
    :param user_group_name: The user group name
    :type user_group_name: str
    """

    _attribute_map = {
        'members': {'key': 'members', 'type': '[UserChildWithEmail]'},
        'user_group_id': {'key': 'userGroupId', 'type': 'int'},
        'user_group_name': {'key': 'userGroupName', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(UserGroupWithMembers, self).__init__(**kwargs)
        self.members = kwargs.get('members', None)
        self.user_group_id = kwargs.get('user_group_id', None)
        self.user_group_name = kwargs.get('user_group_name', None)
