# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportDistributionLogReportSettings(Model):
    """ReportDistributionLogReportSettings.

    :param base_report:
    :type base_report: ~energycap.sdk.models.ReportChild
    :param report_filters: List of filters to apply to the report
    :type report_filters: list[~energycap.sdk.models.FilterResponse]
    """

    _attribute_map = {
        'base_report': {'key': 'baseReport', 'type': 'ReportChild'},
        'report_filters': {'key': 'reportFilters', 'type': '[FilterResponse]'},
    }

    def __init__(self, *, base_report=None, report_filters=None, **kwargs) -> None:
        super(ReportDistributionLogReportSettings, self).__init__(**kwargs)
        self.base_report = base_report
        self.report_filters = report_filters
