# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DataAccessReleaseNoFileRequest(Model):
    """DataAccessReleaseNoFileRequest.

    All required parameters must be populated in order to send to Azure.

    :param account_number: Required. Account Number
     Should be a 12 digit number starting with 2. <span
     class='property-internal'>Required</span>
    :type account_number: str
    :param name_on_bill: Required.  <span
     class='property-internal'>Required</span>
    :type name_on_bill: str
    :param service_address: Required.  <span
     class='property-internal'>Required</span>
    :type service_address: str
    """

    _validation = {
        'account_number': {'required': True},
        'name_on_bill': {'required': True},
        'service_address': {'required': True},
    }

    _attribute_map = {
        'account_number': {'key': 'accountNumber', 'type': 'str'},
        'name_on_bill': {'key': 'nameOnBill', 'type': 'str'},
        'service_address': {'key': 'serviceAddress', 'type': 'str'},
    }

    def __init__(self, *, account_number: str, name_on_bill: str, service_address: str, **kwargs) -> None:
        super(DataAccessReleaseNoFileRequest, self).__init__(**kwargs)
        self.account_number = account_number
        self.name_on_bill = name_on_bill
        self.service_address = service_address
