# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UserGroupResponse(Model):
    """UserGroupResponse.

    :param user_group_id: The user group identifier
    :type user_group_id: int
    :param user_group_name: The user group name
    :type user_group_name: str
    :param description: The user group description
    :type description: str
    :param member_count: The number of users in this group
    :type member_count: int
    :param last_updated: The last time a member was inserted, updated, or
     deleted from the group
    :type last_updated: datetime
    """

    _attribute_map = {
        'user_group_id': {'key': 'userGroupId', 'type': 'int'},
        'user_group_name': {'key': 'userGroupName', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'member_count': {'key': 'memberCount', 'type': 'int'},
        'last_updated': {'key': 'lastUpdated', 'type': 'iso-8601'},
    }

    def __init__(self, **kwargs):
        super(UserGroupResponse, self).__init__(**kwargs)
        self.user_group_id = kwargs.get('user_group_id', None)
        self.user_group_name = kwargs.get('user_group_name', None)
        self.description = kwargs.get('description', None)
        self.member_count = kwargs.get('member_count', None)
        self.last_updated = kwargs.get('last_updated', None)
