# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class VendorDigestActualYearlyResponse(Model):
    """VendorDigestActualYearlyResponse.

    :param vendor_code: The vendor code
    :type vendor_code: str
    :param vendor_info: The vendor info
    :type vendor_info: str
    :param vendor_id: The vendor identifier
    :type vendor_id: int
    :param global_use_unit:
    :type global_use_unit: ~energycap.sdk.models.UnitChild
    :param cost_unit:
    :type cost_unit: ~energycap.sdk.models.UnitChild
    :param updated: The date and time the data was updated
    :type updated: datetime
    :param results: An array of yearly data
    :type results:
     list[~energycap.sdk.models.VendorDigestActualYearlyResponseResults]
    :param commodities: An array of yearly data per commodity
    :type commodities:
     list[~energycap.sdk.models.VendorDigestActualYearlyResponseCommodityData]
    """

    _attribute_map = {
        'vendor_code': {'key': 'vendorCode', 'type': 'str'},
        'vendor_info': {'key': 'vendorInfo', 'type': 'str'},
        'vendor_id': {'key': 'vendorId', 'type': 'int'},
        'global_use_unit': {'key': 'globalUseUnit', 'type': 'UnitChild'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
        'updated': {'key': 'updated', 'type': 'iso-8601'},
        'results': {'key': 'results', 'type': '[VendorDigestActualYearlyResponseResults]'},
        'commodities': {'key': 'commodities', 'type': '[VendorDigestActualYearlyResponseCommodityData]'},
    }

    def __init__(self, *, vendor_code: str=None, vendor_info: str=None, vendor_id: int=None, global_use_unit=None, cost_unit=None, updated=None, results=None, commodities=None, **kwargs) -> None:
        super(VendorDigestActualYearlyResponse, self).__init__(**kwargs)
        self.vendor_code = vendor_code
        self.vendor_info = vendor_info
        self.vendor_id = vendor_id
        self.global_use_unit = global_use_unit
        self.cost_unit = cost_unit
        self.updated = updated
        self.results = results
        self.commodities = commodities
