# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountAlertResponse(Model):
    """AccountAlertResponse.

    :param alert_id:
    :type alert_id: int
    :param begin_date:
    :type begin_date: datetime
    :param end_date:
    :type end_date: datetime
    :param message:
    :type message: str
    :param allow_bill_processing:
    :type allow_bill_processing: bool
    """

    _attribute_map = {
        'alert_id': {'key': 'alertId', 'type': 'int'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'message': {'key': 'message', 'type': 'str'},
        'allow_bill_processing': {'key': 'allowBillProcessing', 'type': 'bool'},
    }

    def __init__(self, *, alert_id: int=None, begin_date=None, end_date=None, message: str=None, allow_bill_processing: bool=None, **kwargs) -> None:
        super(AccountAlertResponse, self).__init__(**kwargs)
        self.alert_id = alert_id
        self.begin_date = begin_date
        self.end_date = end_date
        self.message = message
        self.allow_bill_processing = allow_bill_processing
