# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ListResponse(Model):
    """ListResponse.

    :param list_id: Specific List Identifier
    :type list_id: int
    :param data: Data for the bill list
    :type data: list[list[~energycap.sdk.models.ListResponseListItem]]
    :param field: Definition of the bill list - available filters and columns
    :type field: list[~energycap.sdk.models.ListResponseListField]
    :param meta: Meta data about the list
     Can contain:
     TotalCount - Total number of items that match the filter
     TotalCost - Total Cost of all the items that match the filter
     costUnitInfo - The currency unit
     ErrorMessage - Indicates data fetch error.
    :type meta: dict[str, object]
    """

    _attribute_map = {
        'list_id': {'key': 'listId', 'type': 'int'},
        'data': {'key': 'data', 'type': '[[ListResponseListItem]]'},
        'field': {'key': 'field', 'type': '[ListResponseListField]'},
        'meta': {'key': 'meta', 'type': '{object}'},
    }

    def __init__(self, *, list_id: int=None, data=None, field=None, meta=None, **kwargs) -> None:
        super(ListResponse, self).__init__(**kwargs)
        self.list_id = list_id
        self.data = data
        self.field = field
        self.meta = meta
