# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TaskEdit(Model):
    """TaskEdit.

    All required parameters must be populated in order to send to Azure.

    :param task_note: Required.  <span
     class='property-internal'>Required</span>
    :type task_note: str
    """

    _validation = {
        'task_note': {'required': True},
    }

    _attribute_map = {
        'task_note': {'key': 'taskNote', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(TaskEdit, self).__init__(**kwargs)
        self.task_note = kwargs.get('task_note', None)
