# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarMeterLinkRequest(Model):
    """EnergyStarMeterLinkRequest.

    All required parameters must be populated in order to send to Azure.

    :param meter_id: Required. The meter identifier <span
     class='property-internal'>Required</span>
    :type meter_id: int
    :param pm_meter_id: The Portfolio Manager meter identifier.  Set to null
     to unlink meter. <span class='property-internal'>Required (defined)</span>
    :type pm_meter_id: long
    """

    _validation = {
        'meter_id': {'required': True},
    }

    _attribute_map = {
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'pm_meter_id': {'key': 'pmMeterId', 'type': 'long'},
    }

    def __init__(self, *, meter_id: int, pm_meter_id: int=None, **kwargs) -> None:
        super(EnergyStarMeterLinkRequest, self).__init__(**kwargs)
        self.meter_id = meter_id
        self.pm_meter_id = pm_meter_id
