# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillingPeriodUseUnitChild(Model):
    """BillingPeriodUseUnitChild.

    :param use: The total common use.
    :type use: float
    :param unit:
    :type unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'use': {'key': 'use', 'type': 'float'},
        'unit': {'key': 'unit', 'type': 'UnitChild'},
    }

    def __init__(self, *, use: float=None, unit=None, **kwargs) -> None:
        super(BillingPeriodUseUnitChild, self).__init__(**kwargs)
        self.use = use
        self.unit = unit
