# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CalendarizedSumRequest(Model):
    """CalendarizedSumRequest.

    All required parameters must be populated in order to send to Azure.

    :param sum_meter_ids: Required. Meters in this list will have their use or
     cost added together during the bill calculation <span
     class='property-internal'>Cannot be Empty</span> <span
     class='property-internal'>Required</span>
    :type sum_meter_ids: list[int]
    """

    _validation = {
        'sum_meter_ids': {'required': True},
    }

    _attribute_map = {
        'sum_meter_ids': {'key': 'sumMeterIds', 'type': '[int]'},
    }

    def __init__(self, **kwargs):
        super(CalendarizedSumRequest, self).__init__(**kwargs)
        self.sum_meter_ids = kwargs.get('sum_meter_ids', None)
