# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BaselineProcessorRequestBaselineBill(Model):
    """BaselineProcessorRequestBaselineBill.

    :param bill_id: The identifier of the baseline bill
    :type bill_id: int
    :param is_excluded: Indicates if the bill should be included in the
     baseline regression
    :type is_excluded: bool
    """

    _attribute_map = {
        'bill_id': {'key': 'billId', 'type': 'int'},
        'is_excluded': {'key': 'isExcluded', 'type': 'bool'},
    }

    def __init__(self, *, bill_id: int=None, is_excluded: bool=None, **kwargs) -> None:
        super(BaselineProcessorRequestBaselineBill, self).__init__(**kwargs)
        self.bill_id = bill_id
        self.is_excluded = is_excluded
