# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergySavingsUnit(Model):
    """EnergySavingsUnit.

    :param energy_savings_unit_id: The energy savings unit identifier
    :type energy_savings_unit_id: int
    :param energy_savings_unit_code: The energy savings unit code
    :type energy_savings_unit_code: str
    :param energy_savings_unit_info: The energy savings unit information
    :type energy_savings_unit_info: str
    """

    _attribute_map = {
        'energy_savings_unit_id': {'key': 'energySavingsUnitId', 'type': 'int'},
        'energy_savings_unit_code': {'key': 'energySavingsUnitCode', 'type': 'str'},
        'energy_savings_unit_info': {'key': 'energySavingsUnitInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(EnergySavingsUnit, self).__init__(**kwargs)
        self.energy_savings_unit_id = kwargs.get('energy_savings_unit_id', None)
        self.energy_savings_unit_code = kwargs.get('energy_savings_unit_code', None)
        self.energy_savings_unit_info = kwargs.get('energy_savings_unit_info', None)
