# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PostalCodeResponseWeatherStation(Model):
    """PostalCodeResponseWeatherStation.

    :param weather_station_id: The weather station Id
    :type weather_station_id: int
    :param web_station_id: The web station Id
    :type web_station_id: int
    :param weather_station_code: The weather station code
    :type weather_station_code: str
    :param city: The city of the weather station
    :type city: str
    :param state: The state of the weather station
    :type state: str
    :param country: The country of the weather station
    :type country: str
    """

    _attribute_map = {
        'weather_station_id': {'key': 'weatherStationId', 'type': 'int'},
        'web_station_id': {'key': 'webStationId', 'type': 'int'},
        'weather_station_code': {'key': 'weatherStationCode', 'type': 'str'},
        'city': {'key': 'city', 'type': 'str'},
        'state': {'key': 'state', 'type': 'str'},
        'country': {'key': 'country', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(PostalCodeResponseWeatherStation, self).__init__(**kwargs)
        self.weather_station_id = kwargs.get('weather_station_id', None)
        self.web_station_id = kwargs.get('web_station_id', None)
        self.weather_station_code = kwargs.get('weather_station_code', None)
        self.city = kwargs.get('city', None)
        self.state = kwargs.get('state', None)
        self.country = kwargs.get('country', None)
