# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DynamicListRequest(Model):
    """DynamicListRequest.

    :param filters: Filters to apply to the dynamic list when initializing it
     <span class='property-internal'>Cannot be Empty</span>
    :type filters: list[~energycap.sdk.models.QuickFilter]
    :param reset_columns: Flag indicating whether or not to initialize the
     dynamic list column definitions
    :type reset_columns: bool
    """

    _attribute_map = {
        'filters': {'key': 'filters', 'type': '[QuickFilter]'},
        'reset_columns': {'key': 'resetColumns', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(DynamicListRequest, self).__init__(**kwargs)
        self.filters = kwargs.get('filters', None)
        self.reset_columns = kwargs.get('reset_columns', None)
