# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportDistributionLogDetailsResponse(Model):
    """ReportDistributionLogDetailsResponse.

    :param email_settings:
    :type email_settings:
     ~energycap.sdk.models.ReportDistributionLogEmailSettings
    :param report_settings:
    :type report_settings:
     ~energycap.sdk.models.ReportDistributionLogReportSettings
    :param errors: Detailed errors that may have occurred during report
     distribution run
    :type errors: str
    """

    _attribute_map = {
        'email_settings': {'key': 'emailSettings', 'type': 'ReportDistributionLogEmailSettings'},
        'report_settings': {'key': 'reportSettings', 'type': 'ReportDistributionLogReportSettings'},
        'errors': {'key': 'errors', 'type': 'str'},
    }

    def __init__(self, *, email_settings=None, report_settings=None, errors: str=None, **kwargs) -> None:
        super(ReportDistributionLogDetailsResponse, self).__init__(**kwargs)
        self.email_settings = email_settings
        self.report_settings = report_settings
        self.errors = errors
