# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChargebackWorkflowSettings(Model):
    """Represents workflow settings for chargebacks.

    All required parameters must be populated in order to send to Azure.

    :param allow_advanced_chargeback_settings: Required. Allow or prevent the
     "advanced" dialog to be displayed when running the chargeback processor
     <span class='property-internal'>Required</span>
    :type allow_advanced_chargeback_settings: bool
    """

    _validation = {
        'allow_advanced_chargeback_settings': {'required': True},
    }

    _attribute_map = {
        'allow_advanced_chargeback_settings': {'key': 'allowAdvancedChargebackSettings', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(ChargebackWorkflowSettings, self).__init__(**kwargs)
        self.allow_advanced_chargeback_settings = kwargs.get('allow_advanced_chargeback_settings', None)
