# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BenchmarkSettingsEdit(Model):
    """BenchmarkSettingsEdit.

    :param benchmark1:
    :type benchmark1: ~energycap.sdk.models.BenchmarkEdit
    :param benchmark2:
    :type benchmark2: ~energycap.sdk.models.BenchmarkEdit
    :param benchmark3:
    :type benchmark3: ~energycap.sdk.models.BenchmarkEdit
    """

    _attribute_map = {
        'benchmark1': {'key': 'benchmark1', 'type': 'BenchmarkEdit'},
        'benchmark2': {'key': 'benchmark2', 'type': 'BenchmarkEdit'},
        'benchmark3': {'key': 'benchmark3', 'type': 'BenchmarkEdit'},
    }

    def __init__(self, *, benchmark1=None, benchmark2=None, benchmark3=None, **kwargs) -> None:
        super(BenchmarkSettingsEdit, self).__init__(**kwargs)
        self.benchmark1 = benchmark1
        self.benchmark2 = benchmark2
        self.benchmark3 = benchmark3
