# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChargebackWorkflowDigestResponse(Model):
    """ChargebackWorkflowDigestResponse.

    :param chargeback_workflow_step:
    :type chargeback_workflow_step:
     ~energycap.sdk.models.ChargebackWorkflowStepChild
    :param results: The list of digest results for the latest task executed in
     the specified billing period.
    :type results: list[~energycap.sdk.models.ChargebackWorkflowDigestChild]
    """

    _attribute_map = {
        'chargeback_workflow_step': {'key': 'chargebackWorkflowStep', 'type': 'ChargebackWorkflowStepChild'},
        'results': {'key': 'results', 'type': '[ChargebackWorkflowDigestChild]'},
    }

    def __init__(self, *, chargeback_workflow_step=None, results=None, **kwargs) -> None:
        super(ChargebackWorkflowDigestResponse, self).__init__(**kwargs)
        self.chargeback_workflow_step = chargeback_workflow_step
        self.results = results
