# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillUnexport(Model):
    """BillUnexport.

    All required parameters must be populated in order to send to Azure.

    :param bill_ids: Required.  <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Cannot be Empty</span>
    :type bill_ids: list[int]
    :param export_mode: Required.  <span
     class='property-internal'>Required</span> <span
     class='property-internal'>One of ap, gl </span>
    :type export_mode: str
    """

    _validation = {
        'bill_ids': {'required': True},
        'export_mode': {'required': True},
    }

    _attribute_map = {
        'bill_ids': {'key': 'billIds', 'type': '[int]'},
        'export_mode': {'key': 'exportMode', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(BillUnexport, self).__init__(**kwargs)
        self.bill_ids = kwargs.get('bill_ids', None)
        self.export_mode = kwargs.get('export_mode', None)
