# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class NamedPeriod(Model):
    """This class represents a date period (YYYYMM) which could be an accounting
    period or a billing/calendar period.

    :param period_name: Name of the period to be displayed
     Should be empty if billing period
    :type period_name: str
    :param period: Value of the period in format (YYYYPP)
     PP may be a calendar month (e.g. 01-12) but it could be an accounting
     period (e.g. 01-13)
    :type period: int
    """

    _attribute_map = {
        'period_name': {'key': 'periodName', 'type': 'str'},
        'period': {'key': 'period', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(NamedPeriod, self).__init__(**kwargs)
        self.period_name = kwargs.get('period_name', None)
        self.period = kwargs.get('period', None)
