# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ListActionCustom(Model):
    """ListActionCustom.

    All required parameters must be populated in order to send to Azure.

    :param webhook_id: Required. The webhook identifier that represents the
     custom bill action <span class='property-internal'>Required</span>
    :type webhook_id: int
    """

    _validation = {
        'webhook_id': {'required': True},
    }

    _attribute_map = {
        'webhook_id': {'key': 'webhookId', 'type': 'int'},
    }

    def __init__(self, *, webhook_id: int, **kwargs) -> None:
        super(ListActionCustom, self).__init__(**kwargs)
        self.webhook_id = webhook_id
