# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterDigestGHGYearlyResponseGHGScope(Model):
    """MeterDigestGHGYearlyResponseGHGScope.

    :param ghg_scope_id: GHG scope identifier
    :type ghg_scope_id: int
    :param ghg_scope_code: GHG scope code
    :type ghg_scope_code: str
    :param ghg_scope_info: GHG scope info
    :type ghg_scope_info: str
    :param ghg_scope_type_code: GHG scope type code
    :type ghg_scope_type_code: str
    :param ghg_scope_type_info: GHG scope type code
    :type ghg_scope_type_info: str
    """

    _attribute_map = {
        'ghg_scope_id': {'key': 'ghgScopeId', 'type': 'int'},
        'ghg_scope_code': {'key': 'ghgScopeCode', 'type': 'str'},
        'ghg_scope_info': {'key': 'ghgScopeInfo', 'type': 'str'},
        'ghg_scope_type_code': {'key': 'ghgScopeTypeCode', 'type': 'str'},
        'ghg_scope_type_info': {'key': 'ghgScopeTypeInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(MeterDigestGHGYearlyResponseGHGScope, self).__init__(**kwargs)
        self.ghg_scope_id = kwargs.get('ghg_scope_id', None)
        self.ghg_scope_code = kwargs.get('ghg_scope_code', None)
        self.ghg_scope_info = kwargs.get('ghg_scope_info', None)
        self.ghg_scope_type_code = kwargs.get('ghg_scope_type_code', None)
        self.ghg_scope_type_info = kwargs.get('ghg_scope_type_info', None)
