# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UDFValue(Model):
    """UDFValue.

    :param udf_id: udfId of the UDF being edited <span
     class='property-internal'>Required (defined)</span>
    :type udf_id: int
    :param value:  <span class='property-internal'>Required (defined)</span>
    :type value: str
    """

    _attribute_map = {
        'udf_id': {'key': 'udfId', 'type': 'int'},
        'value': {'key': 'value', 'type': 'str'},
    }

    def __init__(self, *, udf_id: int=None, value: str=None, **kwargs) -> None:
        super(UDFValue, self).__init__(**kwargs)
        self.udf_id = udf_id
        self.value = value
