# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SendDataAccessReleaseRequest(Model):
    """SendDataAccessReleaseRequest.

    All required parameters must be populated in order to send to Azure.

    :param reply_to: Required. Sets the reply-to email address <span
     class='property-internal'>Must be between 0 and 128 characters</span>
     <span class='property-internal'>Required</span>
    :type reply_to: str
    :param recipients: The list of recipient email addresses <span
     class='property-internal'>Cannot be Empty</span>
    :type recipients: list[str]
    :param subject: Required. The subject of the data access release request
     email <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type subject: str
    :param message: Required. The body of the data access release request
     email <span class='property-internal'>Required</span>
    :type message: str
    """

    _validation = {
        'reply_to': {'required': True, 'max_length': 128, 'min_length': 0},
        'subject': {'required': True, 'max_length': 255, 'min_length': 0},
        'message': {'required': True},
    }

    _attribute_map = {
        'reply_to': {'key': 'replyTo', 'type': 'str'},
        'recipients': {'key': 'recipients', 'type': '[str]'},
        'subject': {'key': 'subject', 'type': 'str'},
        'message': {'key': 'message', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(SendDataAccessReleaseRequest, self).__init__(**kwargs)
        self.reply_to = kwargs.get('reply_to', None)
        self.recipients = kwargs.get('recipients', None)
        self.subject = kwargs.get('subject', None)
        self.message = kwargs.get('message', None)
