# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestActualAndCalendarizedYearlyResponseTargetComparison(Model):
    """PlaceDigestActualAndCalendarizedYearlyResponseTargetComparison.

    :param target_year: Target year
    :type target_year: int
    :param target_label: Target label
    :type target_label: str
    :param total_cost: Total cost for the target year
    :type total_cost: float
    :param total_cost_ytd: Total cost for the target year up to the target
     period that corresponds to the current period
    :type total_cost_ytd: float
    :param global_use: Total use for the target year
    :type global_use: float
    :param global_use_ytd: Total use for the target year up to the target
     period that corresponds to the current period
    :type global_use_ytd: float
    """

    _attribute_map = {
        'target_year': {'key': 'targetYear', 'type': 'int'},
        'target_label': {'key': 'targetLabel', 'type': 'str'},
        'total_cost': {'key': 'totalCost', 'type': 'float'},
        'total_cost_ytd': {'key': 'totalCostYtd', 'type': 'float'},
        'global_use': {'key': 'globalUse', 'type': 'float'},
        'global_use_ytd': {'key': 'globalUseYtd', 'type': 'float'},
    }

    def __init__(self, **kwargs):
        super(PlaceDigestActualAndCalendarizedYearlyResponseTargetComparison, self).__init__(**kwargs)
        self.target_year = kwargs.get('target_year', None)
        self.target_label = kwargs.get('target_label', None)
        self.total_cost = kwargs.get('total_cost', None)
        self.total_cost_ytd = kwargs.get('total_cost_ytd', None)
        self.global_use = kwargs.get('global_use', None)
        self.global_use_ytd = kwargs.get('global_use_ytd', None)
