# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillImportProfileRequest(Model):
    """BillImportProfileRequest.

    All required parameters must be populated in order to send to Azure.

    :param profile_code: Required.  <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 64 characters</span>
    :type profile_code: str
    :param column_mapping:
    :type column_mapping: ~energycap.sdk.models.BillImportProfileColumnMapping
    """

    _validation = {
        'profile_code': {'required': True, 'max_length': 64, 'min_length': 0},
    }

    _attribute_map = {
        'profile_code': {'key': 'profileCode', 'type': 'str'},
        'column_mapping': {'key': 'columnMapping', 'type': 'BillImportProfileColumnMapping'},
    }

    def __init__(self, **kwargs):
        super(BillImportProfileRequest, self).__init__(**kwargs)
        self.profile_code = kwargs.get('profile_code', None)
        self.column_mapping = kwargs.get('column_mapping', None)
