# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyProjectType(Model):
    """EnergyProjectType.

    :param energy_project_type_id: The energy project type identifier
    :type energy_project_type_id: int
    :param energy_project_type_code: The energy project type code
    :type energy_project_type_code: str
    :param energy_project_type_info: The energy project type  info
    :type energy_project_type_info: str
    """

    _attribute_map = {
        'energy_project_type_id': {'key': 'energyProjectTypeId', 'type': 'int'},
        'energy_project_type_code': {'key': 'energyProjectTypeCode', 'type': 'str'},
        'energy_project_type_info': {'key': 'energyProjectTypeInfo', 'type': 'str'},
    }

    def __init__(self, *, energy_project_type_id: int=None, energy_project_type_code: str=None, energy_project_type_info: str=None, **kwargs) -> None:
        super(EnergyProjectType, self).__init__(**kwargs)
        self.energy_project_type_id = energy_project_type_id
        self.energy_project_type_code = energy_project_type_code
        self.energy_project_type_info = energy_project_type_info
