# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class NotificationCategory(Model):
    """NotificationCategory.

    :param notification_category_id: The id of the notification category
    :type notification_category_id: int
    :param notification_category_info: The notification category name
    :type notification_category_info: str
    :param notification_category_description: A description of the
     notification category
    :type notification_category_description: str
    """

    _attribute_map = {
        'notification_category_id': {'key': 'notificationCategoryId', 'type': 'int'},
        'notification_category_info': {'key': 'notificationCategoryInfo', 'type': 'str'},
        'notification_category_description': {'key': 'notificationCategoryDescription', 'type': 'str'},
    }

    def __init__(self, *, notification_category_id: int=None, notification_category_info: str=None, notification_category_description: str=None, **kwargs) -> None:
        super(NotificationCategory, self).__init__(**kwargs)
        self.notification_category_id = notification_category_id
        self.notification_category_info = notification_category_info
        self.notification_category_description = notification_category_description
