# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillMeterEdit(Model):
    """BillMeterEdit.

    All required parameters must be populated in order to send to Azure.

    :param meter_id: Required. The meter the line items are assigned to <span
     class='property-internal'>Required</span>
    :type meter_id: int
    :param body_lines: Required.  <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Cannot be Empty</span>
    :type body_lines: list[~energycap.sdk.models.BillMeterBodyLineEdit]
    """

    _validation = {
        'meter_id': {'required': True},
        'body_lines': {'required': True},
    }

    _attribute_map = {
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'body_lines': {'key': 'bodyLines', 'type': '[BillMeterBodyLineEdit]'},
    }

    def __init__(self, *, meter_id: int, body_lines, **kwargs) -> None:
        super(BillMeterEdit, self).__init__(**kwargs)
        self.meter_id = meter_id
        self.body_lines = body_lines
