# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BenchmarkValuesResponse(Model):
    """BenchmarkValuesResponse.

    :param benchmark_values: List of benchmark values and their effective
     dates <span class='property-internal'>Required (defined)</span>
    :type benchmark_values: list[~energycap.sdk.models.BenchmarkValue]
    :param benchmark_indicator: Indicator for which benchmark factor <span
     class='property-internal'>Required (defined)</span>
    :type benchmark_indicator: int
    :param benchmark_info: benchmark info <span
     class='property-internal'>Required (defined)</span>
    :type benchmark_info: str
    :param benchmark_category:
    :type benchmark_category: ~energycap.sdk.models.BenchmarkCategoryResponse
    """

    _attribute_map = {
        'benchmark_values': {'key': 'benchmarkValues', 'type': '[BenchmarkValue]'},
        'benchmark_indicator': {'key': 'benchmarkIndicator', 'type': 'int'},
        'benchmark_info': {'key': 'benchmarkInfo', 'type': 'str'},
        'benchmark_category': {'key': 'benchmarkCategory', 'type': 'BenchmarkCategoryResponse'},
    }

    def __init__(self, *, benchmark_values=None, benchmark_indicator: int=None, benchmark_info: str=None, benchmark_category=None, **kwargs) -> None:
        super(BenchmarkValuesResponse, self).__init__(**kwargs)
        self.benchmark_values = benchmark_values
        self.benchmark_indicator = benchmark_indicator
        self.benchmark_info = benchmark_info
        self.benchmark_category = benchmark_category
