# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GenericCount(Model):
    """GenericCount.

    :param count: Number of items
    :type count: int
    :param description: A short description of the items counted
    :type description: str
    """

    _attribute_map = {
        'count': {'key': 'count', 'type': 'int'},
        'description': {'key': 'description', 'type': 'str'},
    }

    def __init__(self, *, count: int=None, description: str=None, **kwargs) -> None:
        super(GenericCount, self).__init__(**kwargs)
        self.count = count
        self.description = description
