# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountMeterRateResponse(Model):
    """AccountMeterRateResponse.

    :param rate_id: The account meter tariff identifier <span
     class='property-internal'>Required (defined)</span>
    :type rate_id: int
    :param name: The rate name <span class='property-internal'>Required
     (defined)</span>
    :type name: str
    :param rate_code: The rate code <span class='property-internal'>Required
     (defined)</span>
    :type rate_code: str
    :param note: The rate's note <span class='property-internal'>Required
     (defined)</span>
    :type note: str
    :param start_date: The start date for the rate on the account meter <span
     class='property-internal'>Required (defined)</span>
    :type start_date: datetime
    :param end_date: The end date for the rate on the account meter <span
     class='property-internal'>Required (defined)</span>
    :type end_date: datetime
    """

    _attribute_map = {
        'rate_id': {'key': 'rateId', 'type': 'int'},
        'name': {'key': 'name', 'type': 'str'},
        'rate_code': {'key': 'rateCode', 'type': 'str'},
        'note': {'key': 'note', 'type': 'str'},
        'start_date': {'key': 'startDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
    }

    def __init__(self, **kwargs):
        super(AccountMeterRateResponse, self).__init__(**kwargs)
        self.rate_id = kwargs.get('rate_id', None)
        self.name = kwargs.get('name', None)
        self.rate_code = kwargs.get('rate_code', None)
        self.note = kwargs.get('note', None)
        self.start_date = kwargs.get('start_date', None)
        self.end_date = kwargs.get('end_date', None)
