# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarPlaceSubmissionStatusChild(Model):
    """EnergyStarPlaceSubmissionStatusChild.

    :param submission_period: The submission period
    :type submission_period: int
    :param submission_period_display_name: The submission period display name.
     Only populated if the submission period has a custom name.
    :type submission_period_display_name: str
    :param submission_status: The submission status:
     Submitted  - submission has been made for this place and submission period
     Incomplete - no submission has been made for this place and submission
     period, and current billing data is incomplete
     Ready      - no submission has been made for this place and submission
     period, and current billing data is complete
    :type submission_status: str
    """

    _attribute_map = {
        'submission_period': {'key': 'submissionPeriod', 'type': 'int'},
        'submission_period_display_name': {'key': 'submissionPeriodDisplayName', 'type': 'str'},
        'submission_status': {'key': 'submissionStatus', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(EnergyStarPlaceSubmissionStatusChild, self).__init__(**kwargs)
        self.submission_period = kwargs.get('submission_period', None)
        self.submission_period_display_name = kwargs.get('submission_period_display_name', None)
        self.submission_status = kwargs.get('submission_status', None)
