# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillImportWorkflowSettings(Model):
    """Represents workflow settings for bill imports.

    :param error_handling: Determines how bill import errors are handled <span
     class='property-internal'>One of MarkBatchPending, ProcessValidBills
     </span>
    :type error_handling: str
    """

    _attribute_map = {
        'error_handling': {'key': 'errorHandling', 'type': 'str'},
    }

    def __init__(self, *, error_handling: str=None, **kwargs) -> None:
        super(BillImportWorkflowSettings, self).__init__(**kwargs)
        self.error_handling = error_handling
