# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountPeriodRequest(Model):
    """AccountPeriodRequest.

    All required parameters must be populated in order to send to Azure.

    :param period_number: The period number
     When submitted with a list of other account periods, there cannot be more
     than one account period with the same periodNumber <span
     class='property-internal'>Must be between 1 and 12</span> <span
     class='property-internal'>Required (defined)</span>
    :type period_number: int
    :param name: Required. The name of the period <span
     class='property-internal'>Required (defined)</span>
    :type name: str
    """

    _validation = {
        'period_number': {'maximum': 12, 'minimum': 1},
        'name': {'required': True, 'max_length': 32},
    }

    _attribute_map = {
        'period_number': {'key': 'periodNumber', 'type': 'int'},
        'name': {'key': 'name', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AccountPeriodRequest, self).__init__(**kwargs)
        self.period_number = kwargs.get('period_number', None)
        self.name = kwargs.get('name', None)
