# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ApprovalWorkflowSettings(Model):
    """ApprovalWorkflowSettings.

    :param approval_mode_enabled:
    :type approval_mode_enabled: bool
    :param confirm_edit_delete:
    :type confirm_edit_delete: bool
    :param maximum_approval_amount:
    :type maximum_approval_amount: int
    """

    _attribute_map = {
        'approval_mode_enabled': {'key': 'approvalModeEnabled', 'type': 'bool'},
        'confirm_edit_delete': {'key': 'confirmEditDelete', 'type': 'bool'},
        'maximum_approval_amount': {'key': 'maximumApprovalAmount', 'type': 'int'},
    }

    def __init__(self, *, approval_mode_enabled: bool=None, confirm_edit_delete: bool=None, maximum_approval_amount: int=None, **kwargs) -> None:
        super(ApprovalWorkflowSettings, self).__init__(**kwargs)
        self.approval_mode_enabled = approval_mode_enabled
        self.confirm_edit_delete = confirm_edit_delete
        self.maximum_approval_amount = maximum_approval_amount
