# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WeatherImportSettings(Model):
    """WeatherImportSettings.

    :param weather_station_codes: List of weather station codes for which to
     import data
     If omitted or empty, weather data will be imported for all weather
     stations which are assigned to buildings
    :type weather_station_codes: list[str]
    :param begin_date: The begin date for the weather data
     Readings will be imported from this date through the current date
     If omitted or empty, weather data will be imported for the past 31 days
    :type begin_date: datetime
    """

    _attribute_map = {
        'weather_station_codes': {'key': 'weatherStationCodes', 'type': '[str]'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
    }

    def __init__(self, *, weather_station_codes=None, begin_date=None, **kwargs) -> None:
        super(WeatherImportSettings, self).__init__(**kwargs)
        self.weather_station_codes = weather_station_codes
        self.begin_date = begin_date
