# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterGroupChild(Model):
    """MeterGroupChild.

    :param meter_group_id: The meter group identifier
    :type meter_group_id: int
    :param meter_group_code: The meter group code
    :type meter_group_code: str
    :param meter_group_info: The meter group info
    :type meter_group_info: str
    :param auto_group: Indicates if this meter group is an autogroup
    :type auto_group: bool
    :param user_defined_auto_group: Indicates if this meter group is an user
     defined auto group
    :type user_defined_auto_group: bool
    """

    _attribute_map = {
        'meter_group_id': {'key': 'meterGroupId', 'type': 'int'},
        'meter_group_code': {'key': 'meterGroupCode', 'type': 'str'},
        'meter_group_info': {'key': 'meterGroupInfo', 'type': 'str'},
        'auto_group': {'key': 'autoGroup', 'type': 'bool'},
        'user_defined_auto_group': {'key': 'userDefinedAutoGroup', 'type': 'bool'},
    }

    def __init__(self, *, meter_group_id: int=None, meter_group_code: str=None, meter_group_info: str=None, auto_group: bool=None, user_defined_auto_group: bool=None, **kwargs) -> None:
        super(MeterGroupChild, self).__init__(**kwargs)
        self.meter_group_id = meter_group_id
        self.meter_group_code = meter_group_code
        self.meter_group_info = meter_group_info
        self.auto_group = auto_group
        self.user_defined_auto_group = user_defined_auto_group
